package com.ruoyi.zongzhi.controller;

import java.util.List;
import io.swagger.annotations.Api;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zongzhi.domain.TcNetworkArticle;
import com.ruoyi.zongzhi.service.ITcNetworkArticleService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 网络文章Controller
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
@RestController
@RequestMapping("/zongzhi/article")
@Api(tags = " 网络文章")
public class TcNetworkArticleController extends BaseController
{
    @Autowired
    private ITcNetworkArticleService tcNetworkArticleService;

    /**
     * 查询网络文章列表
     */

    @GetMapping("/list")
    public TableDataInfo list(TcNetworkArticle tcNetworkArticle)
    {
        startPage();
        List<TcNetworkArticle> list = tcNetworkArticleService.selectTcNetworkArticleList(tcNetworkArticle);
        return getDataTable(list);
    }

    /**
     * 导出网络文章列表
     */

    @PostMapping("/export")
    public void export(HttpServletResponse response, TcNetworkArticle tcNetworkArticle)
    {
        List<TcNetworkArticle> list = tcNetworkArticleService.selectTcNetworkArticleList(tcNetworkArticle);
        ExcelUtil<TcNetworkArticle> util = new ExcelUtil<TcNetworkArticle>(TcNetworkArticle.class);
        util.exportExcel(response, list, "网络文章数据");
    }

    /**
     * 获取网络文章详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcNetworkArticleService.selectTcNetworkArticleById(id));
    }

    /**
     * 新增网络文章
     */

    @PostMapping
    public AjaxResult add(@RequestBody TcNetworkArticle tcNetworkArticle)
    {
        return toAjax(tcNetworkArticleService.insertTcNetworkArticle(tcNetworkArticle));
    }

    /**
     * 修改网络文章
     */

    @PutMapping
    public AjaxResult edit(@RequestBody TcNetworkArticle tcNetworkArticle)
    {
        return toAjax(tcNetworkArticleService.updateTcNetworkArticle(tcNetworkArticle));
    }

    /**
     * 删除网络文章
     */

	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcNetworkArticleService.deleteTcNetworkArticleByIds(ids));
    }
}
